@@ -8,6 +8,8 @@ from patchwork.common.utils.progress_bar import PatchflowProgressBar
 from patchwork.logger import logger
 from patchwork.step import Step
 from patchwork.steps import (
+    LLM,
+    PR,
     CallLLM,
     CommitChanges,
     CreatePR,
@@ -81,11 +83,8 @@ class AutoFix(Step):
         self.inputs.update(outputs)
 
         for i in range(self.n):
-            outputs = PreparePrompt(self.inputs).run()
-            self.inputs.update(outputs)
-            outputs = CallLLM(self.inputs).run()
-            self.inputs.update(outputs)
-            outputs = ExtractModelResponse(self.inputs).run()
+            self.inputs["prompt_values"] = outputs.get("files_to_patch", [])
+            outputs = LLM(self.inputs).run()
             self.inputs.update(outputs)
 
             for extracted_response in self.inputs["extracted_responses"]:
@@ -113,11 +112,7 @@ class AutoFix(Step):
                 if len(vulns) < 1:
                     break
 
-        outputs = CommitChanges(self.inputs).run()
-        self.inputs.update(outputs)
-        outputs = PreparePR(self.inputs).run()
-        self.inputs.update(outputs)
-        outputs = CreatePR(self.inputs).run()
+        outputs = PR(self.inputs).run()
         self.inputs.update(outputs)
 
         return self.inputs
